<?php

namespace Drupal\default_content_extra\EventSubscriber;

use Drupal\default_content\Event\DefaultContentEvents;
use Drupal\default_content\Event\ImportEvent;
use Drupal\multiversion\Entity\WorkspaceInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class DefaultContentImportSubscriber.
 */
class DefaultContentImportSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[DefaultContentEvents::IMPORT][] = ['removeDuplicateWorkspaces'];
    return $events;
  }

  /**
   * Deletes "live" and "stage" workspaces on import.
   *
   * These are created by Multiversion and Workspace module on install and
   * this will remove workspace duplication and SQL errors.
   *
   * @param \Drupal\default_content\Event\ImportEvent $event
   *   Import Event.
   */
  public function removeDuplicateWorkspaces(ImportEvent $event) {
    foreach ($event->getImportedEntities() as $importedEntity) {
      if (($importedEntity instanceof WorkspaceInterface) && in_array($importedEntity->machine_name->value, ['live', 'stage'])) {
        $importedEntity->delete();
      }
    }
  }

}
